window.Gleam.initSearch([{"doc":"gleemenu","title":"gleemenu","content":"# gleemenu\n\n[![Package Version](https://img.shields.io/hexpm/v/gleemenu)](https://hex.pm/packages/gleemenu)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleemenu/)\n\n```sh\ngleam add gleemenu@1\n```\n```gleam\nimport gleemenu\nimport gleemenu/menu.{Choice, Submenu}\n\ntype Choice {\n  Choice1\n  Choice2\n  Choice3\n  Choice4\n  Choice5\n  Choice6\n}\n\npub fn main() {\n  let menu_tree =\n    [\n      Choice(&quot;choice 1&quot;, Choice1),\n      Choice(&quot;choice 2&quot;, Choice2),\n      Submenu(&quot;submenu 1&quot;, [\n        Choice(&quot;choice 3&quot;, Choice3),\n        Choice(&quot;choice 4&quot;, Choice4),\n      ]),\n      Submenu(&quot;submenu 2&quot;, [\n        Choice(&quot;choice 5&quot;, Choice5),\n        Choice(&quot;choice 6&quot;, Choice6),\n      ]),\n    ]\n    |&gt; menu.new\n\n  let command = menu.Command(run: &quot;dmenu&quot;, with: [])\n\n  use response &lt;- result.try(menu_tree |&gt; show_tree(with: command))\n\n  io.debug(response)\n\n  Ok(Nil)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gleemenu&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"gleemenu/error","title":"Error","content":"pub type Error {\n  InvalidResponse(expected: String, found: String)\n  ParsingFailed(expected: String, found: String)\n  CommandFailed(code: Int, stderr: String)\n}\n\nInvalidResponse(expected: String, found: String)\n\n\nParsingFailed(expected: String, found: String)\n\n\nCommandFailed(code: Int, stderr: String)\n\n\nSynonyms:\ngleemenu/error.Error\ngleemenu/error Error","url":"gleemenu/error.html#Error"},{"doc":"gleemenu/error","title":"command_failed","content":"pub fn command_failed(error: #(Int, String)) -&gt; Error\n\nSynonyms:\ngleemenu/error.command_failed\ngleemenu/error command_failed","url":"gleemenu/error.html#command_failed"},{"doc":"gleemenu/error","title":"gleemenu/error","content":"","url":"gleemenu/error.html"},{"doc":"gleemenu/menu","title":"Command","content":"pub type Command {\n  Command(run: String, with: List(String))\n}\n A `dmenu` command.\n\n What you set this to will depend on what your preferred `dmenu` clone is!\n\n ## Examples:\n \n menu.Command(run: &quot;dmenu&quot;, with: [])\n \n \n menu.Command(run: &quot;rofi&quot;, with: [&quot;-dmenu&quot;])\n \n \n // hack: setting `--cache-file=/dev/null` will prevent `wofi` from\n // reordering the menu items based on which was most recently chosen\n menu.Command(run: &quot;wofi&quot;, with: [&quot;--dmenu&quot;, &quot;--prompt=gleemenu&quot;, &quot;--cache-file=/dev/null&quot;])\n \nCommand(run: String, with: List(String))\n\n\nSynonyms:\ngleemenu/menu.Command\ngleemenu/menu Command","url":"gleemenu/menu.html#Command"},{"doc":"gleemenu/menu","title":"Tree","content":"pub type Tree(t) {\n  Choice(label: String, value: t)\n  Submenu(label: String, choices: List(Tree(t)))\n}\n A menu tree.\n\n \n A `Choice` is an option the user can select that will return the associated `value`.\n \n A `Submenu` will open display another list of choices when selected.\n \n `label` is the text that will be displayed to represent a `Choice` or `Submenu` in the menu tree.\n\n ## Examples:\n \n menu.new([\n   menu.Choice(&quot;choice 1&quot;, 1),\n   menu.Choice(&quot;choice 2&quot;, 2),\n   menu.Choice(&quot;choice 3&quot;, 3),\n ])\n \n \n menu.new([menu.Choice(&quot;yes&quot;, True), menu.Choice(&quot;no&quot;, False)])\n \n \n menu.new([\n   menu.Submenu(&quot;submenu&quot;, [\n     menu.Submenu(&quot;another submenu&quot;, [\n       menu.Choice(&quot;i want an apple&quot;, Apple),\n       menu.Choice(&quot;i want a banana&quot;, Banana),\n       menu.Choice(&quot;i want an orange&quot;, Orange),\n     ]),\n   ]),\n ])\n \nChoice(label: String, value: t)\n\n\nSubmenu(label: String, choices: List(Tree(t)))\n\n\nSynonyms:\ngleemenu/menu.Tree\ngleemenu/menu Tree","url":"gleemenu/menu.html#Tree"},{"doc":"gleemenu/menu","title":"new","content":"pub fn new(choices choices: List(Tree(a))) -&gt; Tree(a)\n A nice-looking way to create a menu tree.\n\n \n menu.new([Choice(&quot;yes&quot;, True), Choice(&quot;no&quot;, False)])\n \n // is equivalent to\n \n menu.Submenu(&quot;&lt;root&gt;&quot;, [Choice(&quot;yes&quot;, True), Choice(&quot;no&quot;, False)])\n \nSynonyms:\ngleemenu/menu.new\ngleemenu/menu new","url":"gleemenu/menu.html#new"},{"doc":"gleemenu/menu","title":"gleemenu/menu","content":"","url":"gleemenu/menu.html"},{"doc":"gleemenu","title":"show","content":"pub fn show(\n  menu command: Command,\n  with choices: List(String),\n) -&gt; Result(String, Error)\n Display a list of choices using the provided `dmenu` command.\nSynonyms:\ngleemenu.show\ngleemenu show","url":"gleemenu.html#show"},{"doc":"gleemenu","title":"show_tree","content":"pub fn show_tree(\n  tree tree: Tree(a),\n  with command: Command,\n) -&gt; Result(a, Error)\n Display a menu tree using the provided `dmenu` command.\n\n You can create a menu tree using `menu.new`!\nSynonyms:\ngleemenu.show_tree\ngleemenu show_tree","url":"gleemenu.html#show_tree"},{"doc":"gleemenu","title":"gleemenu","content":"","url":"gleemenu.html"}]);